@@ -328,7 +328,7 @@ class SolBase(object):
     #===============================
 
     @classmethod
-    def loggingInit(cls, logLevel="INFO", forceReset=False, logCallback=None, logToFile=None):
+    def loggingInit(cls, logLevel="INFO", forceReset=False, logCallback=None, logToFile=None, logToSyslog=True):
         """
         Initialize logging sub system with default settings (console, pre-formatted output)
         :param logLevel: The log level to set. Any value in "DEBUG", "INFO", "WARN", "ERROR", "CRITICAL"
@@ -337,6 +337,8 @@ class SolBase(object):
         :type forceReset: bool
         :param logToFile: If specified, log to file
         :type logToFile: str
+        :pram logToSyslog: If specified, log to syslog
+        :type logToSyslog: bool
         :param logCallback: Callback for unittest
         :return Nothing.
         """
@@ -368,14 +370,15 @@ class SolBase(object):
                 cf.setFormatter(f)
 
             # Syslog handler
-            try:
-                from pythonsol.SysLogger import SysLogger
+            if logToSyslog:
+                try:
+                    from pythonsol.SysLogger import SysLogger
 
-                syslog = SysLogger(logCallback=logCallback)
-                syslog.setLevel(logging.getLevelName(logLevel))
-                syslog.setFormatter(f)
-            except Exception as e:
-                raise Exception("Unable to import SysLogger, e=%s", SolBase.exToStr(e))
+                    syslog = SysLogger(logCallback=logCallback)
+                    syslog.setLevel(logging.getLevelName(logLevel))
+                    syslog.setFormatter(f)
+                except Exception as e:
+                    raise Exception("Unable to import SysLogger, e=%s", SolBase.exToStr(e))
 
             # Initialize
             root = logging.getLogger()
